# -*- coding: utf-8 -*-

"""
***************************************************************************
    SilentProgress.py
    ---------------------
    Date                 : April 2013
    Copyright            : (C) 2013 by Victor Olaya
    Email                : volayaf at gmail dot com
***************************************************************************
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
***************************************************************************
"""

__author__ = 'Victor Olaya'
__date__ = 'April 2013'
__copyright__ = '(C) 2013, Victor Olaya'

# This will get replaced with a git SHA1 when you do a git archive

__revision__ = '$Format:%H$'


class SilentProgress(object):

    def error(self, msg):
        print msg

    def setText(self, text):
        pass

    def setPercentage(self, i):
        pass

    def setInfo(self, msg):
        pass

    def setCommand(self, msg):
        pass

    def setDebugInfo(self, msg):
        pass

    def setConsoleInfo(self, msg):
        pass

    def close(self):
        pass
